Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrValidateFailed = errors.New("some images failed to validate") ErrCopyFailed = errors.New("some images failed to copy") )
Functions ¶
func NewError ¶
func NewError(id int, e error, s *source.Source, d *destination.Destination) error
Types ¶
type CommonOpts ¶
type Loader ¶
type Loader struct {
// Specify the source image registry.
SourceRegistry string
// Specify the source image project.
SourceProject string
// Specify the destination image registry.
DestinationRegistry string
// Specify the destination image project.
DestinationProject string
// Directory is the source archive directory
Directory string
SharedBlobDirPath string
// ArchiveName is the archive file name to be load
ArchiveName string
// contains filtered or unexported fields
}
Loader loads images from hangar archive file to registry server.
func NewLoader ¶
func NewLoader(o *LoaderOpts) (*Loader, error)
func (Loader) SaveFailedImages ¶
func (c Loader) SaveFailedImages() error
type LoaderOpts ¶
type LoaderOpts struct {
CommonOpts
// Specify the source image registry.
SourceRegistry string
// Specify the source image project.
SourceProject string
// Specify the destination image registry.
DestinationRegistry string
// Specify the destination image project.
DestinationProject string
// Directory is the source archive directory
Directory string
SharedBlobDirPath string
// ArchiveName is the archive file name to be load
ArchiveName string
}
type Mirrorer ¶
type Mirrorer struct {
// Override the registry of source image to be copied
SourceRegistry string
// Override the registry of the copied destination image
DestinationRegistry string
// Override the project of source image to be copied
SourceProject string
// Override the project of the copied destination image
DestinationProject string
// contains filtered or unexported fields
}
Mirrorer mirrors multipule images between image registries.
func NewMirrorer ¶
func NewMirrorer(o *MirrorerOpts) (*Mirrorer, error)
func (Mirrorer) SaveFailedImages ¶
func (c Mirrorer) SaveFailedImages() error
type MirrorerOpts ¶
type MirrorerOpts struct {
CommonOpts
SourceRegistry string
DestinationRegistry string
SourceProject string
DestinationProject string
}
type Saver ¶
type Saver struct {
// Override the registry of source image to be copied
SourceRegistry string
// Override the project of source image to be copied
SourceProject string
SharedBlobDirPath string
// ArchiveName is the saved archive file name
ArchiveName string
// contains filtered or unexported fields
}
func (Saver) SaveFailedImages ¶
func (c Saver) SaveFailedImages() error
type SaverOpts ¶
type SaverOpts struct {
CommonOpts
// Override the registry of source image to be copied
SourceRegistry string
// Override the project of source image to be copied
SourceProject string
SharedBlobDirPath string
// ArchiveName is the saved archive file name
ArchiveName string
}
type Syncer ¶
type Syncer struct {
// Override the registry of source image to be copied
SourceRegistry string
// Override the project of source image to be copied
SourceProject string
SharedBlobDirPath string
// ArchiveName is the saved archive file name
ArchiveName string
// contains filtered or unexported fields
}
func NewSyncer ¶
func NewSyncer(o *SyncerOpts) (*Syncer, error)
func (Syncer) SaveFailedImages ¶
func (c Syncer) SaveFailedImages() error
type SyncerOpts ¶
type SyncerOpts struct {
CommonOpts
// Override the registry of source image to be copied
SourceRegistry string
// Override the project of source image to be copied
SourceProject string
SharedBlobDirPath string
// ArchiveName is the saved archive file name
ArchiveName string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.